@@ -4,8 +4,9 @@
 #include "audio.h"
 
 typedef struct {
-    uint8_t aesiv[16], aeskey[16];
-    int32_t fmtp[12];
+  int encrypted;
+  uint8_t aesiv[16], aeskey[16];
+  int32_t fmtp[12];
 } stream_cfg;
 
 typedef uint16_t seq_t;
@@ -18,8 +19,7 @@ void player_stop(void);
 
 void player_volume(double f);
 void player_flush(uint32_t timestamp);
-void player_resync(void);
 
-void player_put_packet(seq_t seqno,uint32_t timestamp, uint8_t *data, int len);
+void player_put_packet(seq_t seqno, uint32_t timestamp, uint8_t *data, int len);
 
 #endif //_PLAYER_H
